broken_doclink

package
v0.11.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 6, 2026 License: MIT Imports: 8 Imported by: 0

Documentation

Overview

Package broken_doclink provides a checker for detecting broken doc links in godoc comments. A doc link is considered broken if it references a symbol or package that doesn't exist (e.g., [nonexistent.Symbol] where Symbol is not exported from the current package, or [unknown/pkg.Func).

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type BrokenDoclinkChecker

type BrokenDoclinkChecker struct{}

BrokenDoclinkChecker checks for broken doc links in godoc comments.

func NewBrokenDoclinkChecker

func NewBrokenDoclinkChecker() *BrokenDoclinkChecker

NewBrokenDoclinkChecker returns a new instance of the corresponding checker.

func (*BrokenDoclinkChecker) Apply

Apply implements the corresponding interface method.

func (*BrokenDoclinkChecker) GetCoveredRules

func (r *BrokenDoclinkChecker) GetCoveredRules() model.RuleSet

GetCoveredRules implements the corresponding interface method.

Jump to