max_len

package
v0.11.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 6, 2026 License: MIT Imports: 9 Imported by: 0

Documentation

Overview

Package max_len provides a checker for maximum line length of godocs.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MaxLenChecker

type MaxLenChecker struct{}

MaxLenChecker checks maximum line length of godocs.

func NewMaxLenChecker

func NewMaxLenChecker() *MaxLenChecker

NewMaxLenChecker returns a new instance of the corresponding checker.

func (*MaxLenChecker) Apply

func (r *MaxLenChecker) Apply(actx *model.AnalysisContext) error

Apply implements the corresponding interface method.

func (*MaxLenChecker) GetCoveredRules

func (r *MaxLenChecker) GetCoveredRules() model.RuleSet

GetCoveredRules implements the corresponding interface method.

Jump to