Documentation
¶
Overview ¶
Package check provides a registry of checkers.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Registry ¶
type Registry struct {
// contains filtered or unexported fields
}
Registry implements a registry of rules.
func NewPopulatedRegistry ¶
func NewPopulatedRegistry() *Registry
NewPopulatedRegistry returns a registry with all supported rules registered.
func NewRegistry ¶
NewRegistry returns a new rule registry instance.
func (*Registry) GetCoveredRules ¶
GetCoveredRules implements the corresponding interface method.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package broken_doclink provides a checker for detecting broken doc links in godoc comments.
|
Package broken_doclink provides a checker for detecting broken doc links in godoc comments. |
|
Package deprecated provides a checker for correct usage of deprecation markers.
|
Package deprecated provides a checker for correct usage of deprecation markers. |
|
Package max_len provides a checker for maximum line length of godocs.
|
Package max_len provides a checker for maximum line length of godocs. |
|
Package no_unused_link provides a checker for unused links in godocs.
|
Package no_unused_link provides a checker for unused links in godocs. |
|
Package pkg_doc provides a checker for package godocs.
|
Package pkg_doc provides a checker for package godocs. |
|
Package require_doc provides a checker that requires symbols to have godocs.
|
Package require_doc provides a checker that requires symbols to have godocs. |
|
Package require_func_docs provides a checker for validating that function godoc comments include documentation for all parameters and return values.
|
Package require_func_docs provides a checker for validating that function godoc comments include documentation for all parameters and return values. |
|
Package shared provides shared utilities for checkers.
|
Package shared provides shared utilities for checkers. |
|
Package start_with_name provides a checker for godocs starting with the symbol name.
|
Package start_with_name provides a checker for godocs starting with the symbol name. |
|
Package stdlib_doclink provides a checker for detecting potential doc links to standard library symbols.
|
Package stdlib_doclink provides a checker for detecting potential doc links to standard library symbols. |
|
internal
Package internal contains internal types for stdlib_doclink checker.
|
Package internal contains internal types for stdlib_doclink checker. |
|
internal/gen
command
gen is a command package that extracts information about stdlib's top-level declarations and generates a JSON.
|
gen is a command package that extracts information about stdlib's top-level declarations and generates a JSON. |
Click to show internal directories.
Click to hide internal directories.