Documentation
¶
Overview ¶
Package broken_doclink provides a checker for detecting broken doc links in godoc comments. A doc link is considered broken if it references a symbol or package that doesn't exist (e.g., [nonexistent.Symbol] where Symbol is not exported from the current package, or [unknown/pkg.Func).
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BrokenDoclinkChecker ¶
type BrokenDoclinkChecker struct{}
BrokenDoclinkChecker checks for broken doc links in godoc comments.
func NewBrokenDoclinkChecker ¶
func NewBrokenDoclinkChecker() *BrokenDoclinkChecker
NewBrokenDoclinkChecker returns a new instance of the corresponding checker.
func (*BrokenDoclinkChecker) Apply ¶
func (r *BrokenDoclinkChecker) Apply(actx *model.AnalysisContext) error
Apply implements the corresponding interface method.
func (*BrokenDoclinkChecker) GetCoveredRules ¶
func (r *BrokenDoclinkChecker) GetCoveredRules() model.RuleSet
GetCoveredRules implements the corresponding interface method.
Click to show internal directories.
Click to hide internal directories.