Documentation
¶
Overview ¶
Package stdlib_doclink provides a checker for detecting potential doc links to standard library symbols.
Index ¶
Constants ¶
const RequireStdlibDoclinkRule = model.RequireStdlibDoclinkRule
RequireStdlibDoclinkRule is the corresponding rule name.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type StdlibDoclinkChecker ¶
type StdlibDoclinkChecker struct{}
StdlibDoclinkChecker checks for proper doc links to stdlib symbols.
func NewStdlibDoclinkChecker ¶
func NewStdlibDoclinkChecker() *StdlibDoclinkChecker
NewStdlibDoclinkChecker returns a new instance of the corresponding checker.
func (*StdlibDoclinkChecker) Apply ¶
func (r *StdlibDoclinkChecker) Apply(actx *model.AnalysisContext) error
Apply implements the corresponding interface method.
func (*StdlibDoclinkChecker) GetCoveredRules ¶
func (r *StdlibDoclinkChecker) GetCoveredRules() model.RuleSet
GetCoveredRules implements the corresponding interface method.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package internal contains internal types for stdlib_doclink checker.
|
Package internal contains internal types for stdlib_doclink checker. |
|
gen
command
gen is a command package that extracts information about stdlib's top-level declarations and generates a JSON.
|
gen is a command package that extracts information about stdlib's top-level declarations and generates a JSON. |
Click to show internal directories.
Click to hide internal directories.